@@ -21,12 +21,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <string.h>
-#include <gtk/gtk.h>
 
 #include "bluetooth-client.h"
 #include "bluetooth-client-private.h"
@@ -50,8 +45,6 @@ int main(int argc, char *argv[])
 	GLogLevelFlags fatal_mask;
 	guint class;
 
-	gtk_init(&argc, &argv);
-
 	fatal_mask = g_log_set_always_fatal (G_LOG_FATAL_MASK);
 	fatal_mask |= G_LOG_LEVEL_WARNING | G_LOG_LEVEL_CRITICAL;
 	g_log_set_always_fatal (fatal_mask);
